A simple IPython kernel for Octave

This requires IPython 3, which is not yet released.

To test it, install with ``setup.py``, then::

    ipython qtconsole --kernel octave

For details of how this works, see IPython's docs on `wrapper kernels
<http://ipython.org/ipython-doc/dev/development/wrapperkernels.html>`_.
